<?php
	/* Rcupration XML */
	class XmlElement
	{
		var $name;
		var $attributes;
		var $content;
		var $children;
	};

	function xml_to_object($xml)
	{
		$parser = xml_parser_create();
		xml_parser_set_option($parser, XML_OPTION_CASE_FOLDING, 0);
		xml_parser_set_option($parser, XML_OPTION_SKIP_WHITE, 1);
		xml_parse_into_struct($parser, $xml, $tags);
		xml_parser_free($parser);
		
		$elements = array();
		$stack = array();
		foreach($tags as $tag)
		{
			$index = count($elements);
			if($tag['type'] == "complete" || $tag['type'] == "open")
			{
				$elements[$index] = new XmlElement;
				$elements[$index]->name = $tag['tag'];
				$elements[$index]->attributes = $tag['attributes'];
				$elements[$index]->content = $tag['value'];
				if($tag['type'] == "open")
				{ 
					$elements[$index]->children = array();
					$stack[count($stack)] = &$elements;
					$elements = &$elements[$index]->children;
				}
			}
			if($tag['type'] == "close")
			{ 
				$elements = &$stack[count($stack) - 1];
				unset($stack[count($stack) - 1]);
			}
		}
		return $elements[0]; 
	}
	
	function lectureXml($file)
	{
		$xml = "";
		$handle = @fopen($file, "r");
		if($handle)
		{
			while(!feof($handle))
			{
				$buffer = fgets($handle, 4096);
				$xml .= $buffer;
			}
			fclose($handle);
		} 
		
		return $xml;
	}
	
	/* Autres fonctions */ 
	//Crer la liste
	function creerListe($outils)
	{					 
		$i = 0;	
		$liste = array();
		
		foreach($outils as $elt)
		{
			$liste[$i] = array(
								'id' 			=> trim($elt->attributes['id']),
								'create_date' 	=> trim($elt->attributes['create_date']),
								'last_update' 	=> trim($elt->attributes['last_update'])
							  );
			
			$outil = array();
			$critiques = array();	
		
			foreach($elt->children as $item)
			{
				if($item->name == 'critique')
					$critiques[] = array('critique' => $item->children);
				else
					array_push_associative($liste[$i], array($item->name => (!empty($item->content)?trim($item->content):$item->children)));	
			
				array_push_associative($liste[$i], array('critiques' => $critiques));
			}
			$i++;
		}
	
		return $liste;
	}
	
	//Ajout  la fin d'un tableau associatif
	function array_push_associative(&$arr) 
	{
	   $args = func_get_args();
	   foreach($args as $arg) 
	   {
	       if(is_array($arg)) 
		   {
	           foreach($arg as $key => $value) 
			   {
	               $arr[$key] = $value;
	               $ret++;
	           }
	       }
		   else
		   {
	           $arr[$arg] = "";
	       }
	   } 
	   
	   return $ret;
	}	
	
	// Tri alphabtique de la liste
	function triAlphaXML($liste)
	{
		$liste_alpha = array();
		foreach ($liste as $key => $titre)
		{
			foreach($titre['main'] as $item)
				if($item->name == 'nom')
					$liste_alpha[$key] = $item->content;
		}
	
		array_multisort($liste_alpha, SORT_ASC, $liste); 		
		
		return $liste;
	}
	
	function toTag($time, $str)
	{
		list($jour, $mois, $annee) = explode('/', $str); 
		$timestamp = mktime (0, 0, 0, $mois, $jour + 15, $annee);
		
		return ($time < $timestamp);
	}
		
	function clearCompatibles($table)
	{
		$tmp = array();
		foreach($table as $item)
		{
			array_push_associative($tmp, array($item->attributes['id'] => array('libelle' => $item->attributes['libelle'], 'href' => $item->attributes['href'])));
		} 
		
		return $tmp;
	}
	
	function clearCategories($table)
	{
		$tmp = array();
		foreach($table as $item)
		{
			$tmp[] = array('id' => trim($item->attributes['id']), 'libelle' => trim($item->attributes['libelle']));
		} 
		
		return $tmp;
	}
	
	function recupCat($cat)
	{
		$infos = array();
		$i = 0;
		
		foreach($cat as $info)
		{
			$infos[] = $info->attributes['id'];
		}
		return $infos;
	}
		
	function recupMain($main)
	{
		$infos = array();
		$i = 0;
		
		foreach($main as $info)
		{
			array_push_associative($infos, array($info->name => trim($info->content)));
		}
		
		return $infos;
	}
	
	function recupEditeur($editeur)
	{
		$infos = array();
		
		foreach($editeur as $info)
		{
			if($info->name == 'telechargement')
			{
				array_push_associative($infos, array(
														'telechargement' 	=> trim($info->children[0]->content),
														'miroir'			=> trim($info->children[1]->content)
													)
									   );
			}
			else
			{
				array_push_associative($infos, array($info->name => trim($info->content)));
			}
		}
		
		return $infos;
	}
	
	function recupCritiques($critiques)
	{
		$infos = array();
		
		foreach($critiques as $info)
		{
			$redacteur = '';
			$profil = '';
			$note = '';
			$paragraph = array();
			
			foreach($info['critique'] as $child)
			{
				if($child->name == 'paragraph')
				{
					$paragraph[] = trim($child->content);
				}
				else if($child->name == 'note')
					$note = trim($child->content);
				else if($child->name == 'redacteur')
				{
					$redacteur = trim($child->children[0]->content);
					$profil = trim($child->children[1]->content);	
				}
			}
			
			$infos[] = array(
								'redacteur' => $redacteur,
								'profil'	=> $profil,
								'note'		=> $note,
								'paragraph'	=> $paragraph
							); 
		}
		
		return $infos;
	}
	
	function calculNote($critiques)
	{
		$note = 0;
		$total = 0;
		
		if(!empty($critiques))
		{
			foreach($critiques as $critique)
			{
				$note += intval(trim($critique['note'])); 
				if(!empty($critique['note']))
					$total++;
			}
		}
		return ($note / $total);
	}
	
	function recupLibelle($categories, $id)
	{
		foreach($categories as $item)
		{
			if($item['id'] == $id)
				return $item['libelle'];
		}
	}
		
?>
